##--------constant data analysis-----------##

##install packages
install.packages("ggplot2")
install.packages("dplyr")
install.packages("arm")
install.packages("car")



##download packages
library(ggplot2)
library(plyr)

##Read in data

survival<-read.table("constantdata.txt",header=T)
survival
attach(survival)

## need to clean up data - need to remove rows where dead larvae is less than 0

survival <-subset(survival, dead_larvae>-1)


## split the data by wasp vs. no wasp treatments 

subnowasp <- subset(survival, wasp =="Lb-")
subnowasp

subwasp <- subset(survival, wasp =="Lb+")
subwasp


## statistics 

## summary statistics for larva-to-adult survival

library(dplyr)

subnowasp %>%
  group_by(symbiont, temp) %>%
  summarize(avg=mean(larvae_survival), n=n(), sd=sd(larvae_survival), se=sd/sqrt(n))


subnowasp %>%
  group_by(symbiont) %>%
  summarize(avg=mean(larvae_survival), n=n(), sd=sd(larvae_survival), se=sd/sqrt(n))


subwasp %>%
  group_by(symbiont, temp) %>%
  summarize(avg=mean(larvae_survival), n=n(), sd=sd(larvae_survival), se=sd/sqrt(n))

subwasp %>%
  group_by(symbiont) %>%
  summarize(avg=mean(larvae_survival), n=n(), sd=sd(larvae_survival), se=sd/sqrt(n))

subwasp %>%
  group_by(temp) %>%
  summarize(avg=mean(larvae_survival), n=n(), sd=sd(larvae_survival), se=sd/sqrt(n))


###summary statistics for wasp larva-to-adult survival

subwasp %>%
  group_by(symbiont, temp) %>%
  summarize(avg=mean(wasp_survival), n=n(), sd=sd(wasp_survival), se=sd/sqrt(n))

subwasp %>%
  group_by(temp) %>%
  summarize(avg=mean(wasp_survival), n=n(), sd=sd(wasp_survival), se=sd/sqrt(n))

subwasp %>%
  group_by(symbiont) %>%
  summarize(avg=mean(wasp_survival), n=n(), sd=sd(wasp_survival), se=sd/sqrt(n))


## with binomial errors we need to give the number of 'failures' as well as the number of successes 
## in a two vector response variable. To do this we use the function 'cbind' - which combines two
## columns into a vector in this order number of successes (emerging flies or wasps), 
## number of failures (everything else).

##-------------------------- NO WASP ANALYSIS ----------------------------##


##---------------------- Fly larva-to-adult survival ---- ---------------###

## first see whether in the absence of wasps, spiroplasma or temperature has an affect on survival

Fit <- cbind(subnowasp$total_fly,subnowasp$not_fly)

as.factor(temp)

m1<-glm(Fit~as.factor(temp)*symbiont, quasibinomial(), data = subnowasp)
summary(m1)
car::Anova(m1, test.statistic = "F")

hist(resid(m1))

par(mfrow=c(2,2))
plot(m1)

##-------------------------- WASP ANALYSIS ----------------------------##


##---------------------- Fly larva-to-adult survival ---- ---------------###

Fit2 <- cbind(subwasp$total_fly,subwasp$not_fly)

m2<-glm(Fit2~as.factor(temp)*symbiont, quasibinomial(), data = subwasp)
summary(m2)
car::Anova(m2, test.statistic = "F")


hist(resid(m2))

par(mfrow=c(2,2))
plot(m2)


##---------------------- wasp larva-to-adult survival ---------------------##


WFit <- cbind(subwasp$total_wasp, subwasp$not_wasp)

wm1<-glm(WFit~as.factor(temp)*symbiont, family=quasibinomial, data = subwasp)
car::Anova(wm1, test.statistic = "F")
summary(wm1)


hist(resid(wm1))
par(mfrow=c(2,2))
plot(wm1)


##-------------------- plots ----------------------------------##

##need to find means of failedpupae, failed larvae, number of flies and number of wasps split between wasp strain
##and spiroplasma strain for each treatment - this can be exported into an excel file to then find the binom CI

require(plyr)

cdata1 <- ddply(survival, c("wasp", "symbiont", "temp"), summarise,
                N    = length(total_fly),
                mean = mean(total_fly),
                sd   = sd(total_fly),
                se   = sd / sqrt(N))

cdata1
cdata1$emerge="fly"


###repeat this for each strain for failed pupae, failed larvae and wasps
### need to export this data into excel to make a new data frame with means to force ggplot to make a graph

cdata2 <- ddply(survival, c("wasp", "symbiont", "temp"), summarise,
                N    = length(total_wasp),
                mean = mean(total_wasp),
                sd   = sd(total_wasp),
                se   = sd / sqrt(N))

cdata2
cdata2$emerge="wasps"


cdata3 <- ddply(survival, c("wasp", "symbiont", "temp"), summarise,
                N    = length(failed_pupae),
                mean = mean(failed_pupae),
                sd   = sd(failed_pupae),
                se   = sd / sqrt(N))

cdata3
cdata3$emerge="failed pupae"

cdata4 <- ddply(survival, c("wasp", "symbiont", "temp"), summarise,
                N    = length(dead_larvae),
                mean = mean(dead_larvae),
                sd   = sd(dead_larvae),
                se   = sd / sqrt(N))

cdata4
cdata4$emerge="failed larvae"


### merge all 4 data frames
total <- rbind(cdata1, cdata2, cdata3, cdata4)
total


### merge 
complete <- rbind(total)
complete


##need to multiple 'N' by 30 for number of larvae - replace column
complete$N <- complete$N * 30
complete

##need to divide 'mean' by 30 for proportion - make new column
complete$prop <- complete$mean / 30
complete

##need to remove no wasp 'wasp' treatments
complete <- complete[-c(13, 14, 15, 16, 17, 18), ]


### need to make binomial error bars
library(binom)
library(dplyr)

# calculate CI
prop.ci <- binom.confint(complete$prop * complete$N, complete$N, conf.level = 0.95, methods= "logit", complete)

# bind to the dataframe
complete <- bind_cols(complete, prop.ci)    


## make plot
require(ggplot2)

pd<-position_dodge(0.9)

symbiont1 <- c(
  "CS" = "Uninfected",
  "S+" = "Infected")

treatment <- c("Lb-" = "No wasp control", "Lb+" = "Wasp treatment")
my_x_title <- expression(paste(italic("Spiroplasma")," infection status"))

plotwasp3 <- ggplot(complete, aes(x=symbiont, weight=prop, ymin=upper, ymax=lower, fill=emerge)) +
  geom_bar(position=position_dodge(0.9), aes(y=prop), stat="identity") +
  facet_grid(facets = wasp ~ temp, labeller = as_labeller(c(`21` = "21C",`23` = "23C", `25` = "25C", `Lb+` = "Wasp treatment", `Lb-` = "No wasp control"))) + 
  scale_fill_manual(values=c("#7B0E11", "#D67678", "#28774F", "#2B4B6F"), labels = c("Dead larvae", "Dead pupae", "Flies", "Wasps")) +
  theme_grey(base_size = 15) +
  ylim(0,1) +
  scale_x_discrete(breaks=c("CS","S+"),
                   labels=c("S-", "S+")) +
  theme(legend.title = element_blank(), axis.text.x = element_text(size= 15), plot.title=element_text(hjust=0.5), legend.key.size = unit(1, 'cm'), legend.text = element_text(size=20)) +
  xlab(my_x_title) +
  ylab("Proportion of individuals") +
  labs(tag="C", title="Constant") +
  geom_errorbar(position=pd, aes(x=symbiont, y=prop, 
                                 ymin = upper, ymax = lower), width=0.2, data = complete)

plotwasp3
leg <- get_legend(plotwasp3)



leg
pdf("preattack.pdf")
plot(plotwasp)
dev.off() 

### save plot as 1000 x 1100


####---------further analysis on 23 AND 25 temperature only----------------########

subwasptemp <-subset(subwasp, temp =="25"| temp =="23")
subwasptemp


Fit2 <- cbind(subwasptemp$total_fly,subwasptemp$not_fly)

m2<-glm(Fit2~symbiont*as.factor(temp), binomial(), data = subwasptemp)
summary(m2)
car::Anova(m2, test.statistic = "F")
73.342/36 #over dispersion

m2<-glm(Fit2~symbiont*as.factor(temp), quasibinomial(), data = subwasptemp)
summary(m2)
car::Anova(m2, test.statistic = "F")


hist(resid(m2.1))

par(mfrow=c(2,2))
plot(m2.1)